==> tdm_2.0.0.tar.gz: tdm/R/all.Oxtcrss.R <==
all.Oxtcrss<-function(){
     cat("\n")                                                                      
     cat("--------------------------------------------------------\n")
     cat("    --Oxtriphylline CR input data information--         \n")
     note_for_Thecrss_input()
     cat("--------------------------------------------------------\n")  
     cat("\n")
     note_for_close_window()
     OxtcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                   
     OxtcrSSpar<-edit(OxtcrSSpar)                                                                                                                    
     OxtcrSSpar<-ycheck(OxtcrSSpar)   
     cat("\n")                                                                                                                 
     Oxtcr.ss(OxtcrSSpar[8,2],OxtcrSSpar[7,2],OxtcrSSpar[6,2],OxtcrSSpar[3,2],OxtcrSSpar[2,2],OxtcrSSpar[5,2],OxtcrSSpar[1,2],OxtcrSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline CR output data information--           \n")
     note_for_Thecr_output()
     cat("-----------------------------------------------------------\n")   
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(0.65,OxtcrSSpar[6,2],OxtcrSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")     
     show(coutput)
     cat("\n")   
     Oxtcr.more()          
}

==> tdm_2.2.5.tar.gz: tdm/R/all.Oxtcrss.R <==
all.Oxtcrss<-function(){
     cat("\n")                                                                      
     cat("--------------------------------------------------------\n")
     cat("    --Oxtriphylline CR input data information--         \n")
     note_for_Thecrss_input()
     cat("--------------------------------------------------------\n")  
     cat("\n")
     note_for_close_window()
     OxtcrSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","c (mg/L)"),value=c(0))                   
     OxtcrSSpar<-edit(OxtcrSSpar)                                                                                                                    
##     OxtcrSSpar<-ycheck(OxtcrSSpar)   
     cat("\n")                                                                                                                 
     Oxtcr.ss(OxtcrSSpar[8,2],OxtcrSSpar[7,2],OxtcrSSpar[6,2],OxtcrSSpar[3,2],OxtcrSSpar[2,2],OxtcrSSpar[5,2],OxtcrSSpar[1,2],OxtcrSSpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline CR output data information--           \n")
     note_for_Thecr_output()
     cat("-----------------------------------------------------------\n")   
     show(samplesStats("*"))
     cat("\n") 
     C<-TheCRcpr(0.65,OxtcrSSpar[6,2],OxtcrSSpar[7,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Css_pr (mg/L)")     
     show(coutput)
     cat("\n")   
     Oxtcr.more()          
}
